package com.community.huiju.service.impl;

import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import com.community.commom.constant.Constant;
import com.community.commom.mode.ResponseBean;
import com.community.commom.session.UserElement;
import com.community.commom.utils.AccountValidatorUtil;
import com.community.huiju.dao.TpPhaseMapper;
import com.community.huiju.model.TaUser;
import com.community.huiju.model.TpBuildingOwnerInfo;
import com.community.huiju.model.TpPhase;
import com.community.huiju.service.BuildingTreeServiceI;
import org.apache.poi.hssf.usermodel.HSSFWorkbook;
import org.apache.poi.ss.usermodel.Row;
import org.apache.poi.ss.usermodel.Sheet;
import org.apache.poi.ss.usermodel.Workbook;
import org.apache.poi.xssf.usermodel.XSSFWorkbook;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.web.multipart.MultipartFile;

import java.time.LocalDateTime;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @author FXF
 * @date 2019-04-01
 */
@Service("buildingTreeService")
public class BuildingTreeServiceImpl implements BuildingTreeServiceI {
	
	public static final Logger logger = LoggerFactory.getLogger(BuildingOwnerInfoServiceImpl.class);
	
	@Autowired
	private TpPhaseMapper tpPhaseMapper;
	/**
	 * 获取整个小区的基础数据
	 *
	 * @param file
	 * @return
	 */
	@Override
	public ResponseBean getExcelData(MultipartFile file) {
		ResponseBean responseBean = new ResponseBean();
		List<TpBuildingOwnerInfo> list = new ArrayList<>();
		if (file == null) {
			responseBean.addError("对象不能为空");
			return responseBean;
		}
		//获取文件的名字
		String originalFilename = file.getOriginalFilename();
		Workbook workbook = null;
		try {
			if (originalFilename.endsWith(Constant.SUFFIX_2003)) {
				workbook = new HSSFWorkbook(file.getInputStream());
			} else if (originalFilename.endsWith(Constant.SUFFIX_2007)) {
				workbook = new XSSFWorkbook(file.getInputStream());
			}
		} catch (Exception e) {
			logger.info(originalFilename);
			e.printStackTrace();
			responseBean.addError("格式错误");
			return responseBean;
		}
		if (workbook == null) {
			logger.info(originalFilename);
			responseBean.addError("格式错误");
			return responseBean;
		} else {
			List<String> temBuildingList = new ArrayList<String>();
			//获取一个sheet也就是一个工作簿
			Sheet sheet = workbook.getSheetAt(0);
			int lastRowNum = sheet.getLastRowNum();
			//从第一行开始第一行一般是标题
			for (int j = 3; j <= lastRowNum; j++) {
				Row row = sheet.getRow(j);
				TpBuildingOwnerInfo tpBuildingOwnerInfo = new TpBuildingOwnerInfo();
				String phase = row.getCell(0).getStringCellValue().trim();
				String building = row.getCell(1).getStringCellValue().trim();
				String unit = row.getCell(2).getStringCellValue().trim();
				String level = row.getCell(3).getStringCellValue().trim();
				String roomNo = row.getCell(4).getStringCellValue().trim();
				
				int currentRow = j+1;
				if (StringUtils.isEmpty(phase)){
					responseBean.addError("第" + currentRow + "行" + "期/区不能为空!");
					return responseBean;
				}
				if (StringUtils.isEmpty(building)){
					responseBean.addError("第" + currentRow + "行" + "期/区不能为空!");
					return responseBean;
				}
				if (StringUtils.isEmpty(unit)){
					responseBean.addError("第" + currentRow + "行" + "期/区不能为空!");
					return responseBean;
				}
				if (StringUtils.isEmpty(level)){
					responseBean.addError("第" + currentRow + "行" + "期/区不能为空!");
					return responseBean;
				}
				if (StringUtils.isEmpty(roomNo)){
					responseBean.addError("第" + currentRow + "行" + "期/区不能为空!");
					return responseBean;
				}
				
				String buildingInfo = phase + building + unit + level + roomNo;
				if (temBuildingList.contains(buildingInfo)){
					logger.info("存在重复房源:{}",buildingInfo);
					responseBean.addError("第"+ currentRow +"行存在重复房源");
					return responseBean;
				}
				
				//把数据塞入temList校验是否有重复的数据
				temBuildingList.add(buildingInfo);
				//构建数据
				tpBuildingOwnerInfo.setPhaseName(phase);
				tpBuildingOwnerInfo.setBuildingName(building);
				tpBuildingOwnerInfo.setUnitName(unit);
				tpBuildingOwnerInfo.setLevelName(level);
				tpBuildingOwnerInfo.setName(roomNo);
				list.add(tpBuildingOwnerInfo);
			}
		}
		//构建分页
		Map<String,Object> data = new HashMap<String, Object>();
		data.put("list",list);
		data.put("total",list.size());
		
		responseBean.addSuccess(data);
		return responseBean;
	}
	
	/**
	 * 上传小区的基础数据
	 *
	 * @param file
	 * @param userElement
	 * @return
	 */
	@Override
	public ResponseBean submitExcelData(MultipartFile file, UserElement userElement) {
		ResponseBean responseBean = new ResponseBean();
		responseBean = getExcelData(file);
		if (!responseBean.getCode().equals(Constant.RESPONSE_SUCCESS)){
			return responseBean;
		}
		//获取要上传的数据
		Map<String,Object> map = (Map<String, Object>) responseBean.getData();
		List<TpBuildingOwnerInfo> list = (List<TpBuildingOwnerInfo>) map.get("list");
		
		//入库
		Integer communityId = userElement.getCommunityId();
		
		//保存数据到表中--拆分数据
		String state = saveBuildingTreeData(communityId,list);
		responseBean.addSuccess("success");
		return responseBean;
	}
	
	private String saveBuildingTreeData(Integer communityId, List<TpBuildingOwnerInfo> list) {
		String lastPhaseName = "";
		for (int i = 0; i < list.size(); i++){
		
		}
		return "";
	}
}
